og-fetcher
==========
Open Graph fetcher for python.

Usage
-----
.. code:: python

  from og_fetcher import fetch

  og_data = fetch('http://ogp.me')

Installation
------------
.. code::

  pip install og-fetcher
